@@ -12,16 +12,19 @@ from ._core.message import (
     QueryBus,
     command_handler,
     event_handler,
-    get_command_bus,
-    get_event_bus,
-    get_query_bus,
+    new_command_bus,
+    new_event_bus,
+    new_query_bus,
     query_handler,
 )
 from ._core.middleware import Middleware, MiddlewareResult
+from ._core.related_events import RelatedEvents
+from ._core.scope import CQScope
 
 __all__ = (
     "AnyCommandBus",
     "Bus",
+    "CQScope",
     "Command",
     "CommandBus",
     "DTO",
@@ -33,10 +36,11 @@ __all__ = (
     "Pipe",
     "Query",
     "QueryBus",
+    "RelatedEvents",
     "command_handler",
     "event_handler",
-    "get_command_bus",
-    "get_event_bus",
-    "get_query_bus",
+    "new_command_bus",
+    "new_event_bus",
+    "new_query_bus",
     "query_handler",
 )
